@@ -191,7 +191,7 @@ void ConnectionMapping::parsePid()
     std::array<char, 100> buffer;
 
     auto fdPath = "/proc/%/fd"s;
-    // Ensure the string has enough space to accomodate large PIDs
+    // Ensure the string has enough space to accommodate large PIDs
     fdPath.reserve(30);
 
     // The only way to get a list of PIDs is to list the contents of /proc.
@@ -225,6 +225,9 @@ void ConnectionMapping::parsePid()
             // /proc/PID/fd contains symlinks for each open fd in the process.
             // The symlink target contains information about what the fd is about.
             auto size = readlinkat(dirfd(fdDir), fd->d_name, buffer.data(), 99);
+            if (size < 0) {
+                continue;
+            }
             buffer[size] = '\0';
 
             auto view = std::string_view(buffer.data(), 100);
