@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2020 Arjen Hiemstra <ahiemstra@heimr.nl>
+    SPDX-FileCopyrightText: 2020 Arjen Hiemstra <ahiemstra@heimr.nl>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #pragma once
@@ -28,7 +15,6 @@
 
 namespace KSysGuard
 {
-
 /**
  * Convenience subclass of SensorProperty that reads a sysfs file and uses the result as value.
  */
@@ -38,7 +24,7 @@ class SYSTEMSTATS_EXPORT SysFsSensor : public SensorProperty
 
 public:
     SysFsSensor(const QString &id, const QString &path, SensorObject *parent);
-    ~SysFsSensor();
+    ~SysFsSensor() override;
 
     /**
      * Set the function used to convert the data from sysfs to the value of this sensor.
@@ -47,7 +33,7 @@ public:
      * By default this is set to `std::atoll` or in other words, any numeric value
      * should automatically be converted to a proper QVariant.
      */
-    void setConvertFunction(const std::function<QVariant(const QByteArray&)> &function);
+    void setConvertFunction(const std::function<QVariant(const QByteArray &)> &function);
 
     /**
      * Update this sensor.
